.. _gwcs-schemas:
   
GWCS Schema Definitions
=======================

WCS object
----------

.. toctree::
  :maxdepth: 1
	     
  wcs-1.0.0.rst 
  step-1.0.0.rst

Coordinate Frames
-----------------

.. toctree::
  :maxdepth: 1
	     
  celestial_frame-1.0.0.rst
  frame-1.0.0.rst
  spectral_frame-1.0.0.rst
  frame2d-1.0.0.rst
  temporal_frame-1.0.0.rst
  composite_frame-1.0.0.rst

Transforms
----------

.. toctree::
  :maxdepth: 1
	     
  label_mapper-1.0.0.rst
  regions_selector-1.0.0.rst
